==> pmml-model-gwt-1.4.10.jar: org/dmg/pmml/ModelStats.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.jpmml.model.annotations.Added;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "univariateStats",
    "multivariateStats"
})
@XmlRootElement(name = "ModelStats", namespace = "http://www.dmg.org/PMML-4_3")
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "extensions",
    "univariateStats",
    "multivariateStats"
})
public class ModelStats
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<ModelStats>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "UnivariateStats", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("UnivariateStats")
    private List<UnivariateStats> univariateStats;
    @XmlElement(name = "MultivariateStats", namespace = "http://www.dmg.org/PMML-4_3")
    @Added((org.dmg.pmml.Version.PMML_4_1))
    @JsonProperty("MultivariateStats")
    private List<MultivariateStats> multivariateStats;
    private final static long serialVersionUID = 67305487L;

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public ModelStats addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasUnivariateStats() {
        return ((this.univariateStats!= null)&&(this.univariateStats.size()> 0));
    }

    public List<UnivariateStats> getUnivariateStats() {
        if (univariateStats == null) {
            univariateStats = new ArrayList<UnivariateStats>();
        }
        return this.univariateStats;
    }

    public ModelStats addUnivariateStats(UnivariateStats... univariateStats) {
        getUnivariateStats().addAll(Arrays.asList(univariateStats));
        return this;
    }

    public boolean hasMultivariateStats() {
        return ((this.multivariateStats!= null)&&(this.multivariateStats.size()> 0));
    }

    public List<MultivariateStats> getMultivariateStats() {
        if (multivariateStats == null) {
            multivariateStats = new ArrayList<MultivariateStats>();
        }
        return this.multivariateStats;
    }

    public ModelStats addMultivariateStats(MultivariateStats... multivariateStats) {
        getMultivariateStats().addAll(Arrays.asList(multivariateStats));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasUnivariateStats()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getUnivariateStats());
            }
            if ((status == VisitorAction.CONTINUE)&&hasMultivariateStats()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getMultivariateStats());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.5.0.jar: org/dmg/pmml/ModelStats.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.jpmml.model.annotations.Added;

@XmlRootElement(name = "ModelStats", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "univariateStats",
    "multivariateStats"
})
@JsonRootName("ModelStats")
@JsonPropertyOrder({
    "extensions",
    "univariateStats",
    "multivariateStats"
})
public class ModelStats
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<ModelStats>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "UnivariateStats", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("UnivariateStats")
    private List<UnivariateStats> univariateStats;
    @XmlElement(name = "MultivariateStats", namespace = "http://www.dmg.org/PMML-4_4")
    @Added((org.dmg.pmml.Version.PMML_4_1))
    @JsonProperty("MultivariateStats")
    private List<MultivariateStats> multivariateStats;
    private final static long serialVersionUID = 67371009L;

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public ModelStats addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasUnivariateStats() {
        return ((this.univariateStats!= null)&&(this.univariateStats.size()> 0));
    }

    public List<UnivariateStats> getUnivariateStats() {
        if (univariateStats == null) {
            univariateStats = new ArrayList<UnivariateStats>();
        }
        return this.univariateStats;
    }

    public ModelStats addUnivariateStats(UnivariateStats... univariateStats) {
        getUnivariateStats().addAll(Arrays.asList(univariateStats));
        return this;
    }

    public boolean hasMultivariateStats() {
        return ((this.multivariateStats!= null)&&(this.multivariateStats.size()> 0));
    }

    public List<MultivariateStats> getMultivariateStats() {
        if (multivariateStats == null) {
            multivariateStats = new ArrayList<MultivariateStats>();
        }
        return this.multivariateStats;
    }

    public ModelStats addMultivariateStats(MultivariateStats... multivariateStats) {
        getMultivariateStats().addAll(Arrays.asList(multivariateStats));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasUnivariateStats()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getUnivariateStats());
            }
            if ((status == VisitorAction.CONTINUE)&&hasMultivariateStats()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getMultivariateStats());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
